#!/usr/bin/env python
# -*- coding: utf-8 -*-
version = '0.1'

# Copyright John Thornton 2014

import os
import sys
import gtk
import cairo
import math

if sys.platform.startswith('linux'):
  current_path = os.path.dirname(os.path.realpath(__file__)) + '/'
  sys.path.append(current_path + '/data')

class lathe:
  def __init__(self):
    self.builder = gtk.Builder()
    self.builder.add_from_file(current_path + "data/lathe.glade")
    self.builder.connect_signals(self)
    self.aboutdialog = self.builder.get_object("aboutdialog")
    self.aboutdialog.set_version(version)
    self.message_dialog = self.builder.get_object("messagedialog")
    self.clipboard = gtk.clipboard_get()
    self.arc_draw = self.builder.get_object('hbox4')

    # Create an area to draw in:
    self.drawing_area = gtk.DrawingArea()
    self.drawing_area.set_size_request(200, 200)
    self.arc_draw.pack_start(self.drawing_area)
    self.drawing_area.connect("expose-event", self.expose_handler)
    self.drawable = self.drawing_area.window

    # get info
    self.environment_keys = self.builder.get_object('environment_label')
    self.linuxcnc_keys = ['LINUXCNC_HELP_DIR', 'LINUXCNC_HOME',
      'AXIS_PROGRESS_BAR', 'LINUXCNC_LANG_DIR', 'LINUXCNC_EMCSH',
      'LINUXCNCVERSION', 'HALCMD', 'LINUXCNC_TCL_DIR']
    try:
      self.environment = [key + ' ' + os.environ[key] + '\n' for key in self.linuxcnc_keys]
      self.InAxis = True
    except KeyError:
      print 'Running Standalone'
      self.InAxis = False
    print ';' + str(self.InAxis)
    self.environment_keys.set_text(''.join(self.environment))


    # setup the main window
    self.window = self.builder.get_object("window1")
    self.window.set_title("Lathe G code Generator")
    self.window.show_all()

  # This function will be called whenever the drawing area is exposed:
  def expose_handler(self, widget, event):
    self.context = widget.window.cairo_create()
    #self.context.rectangle(event.area.x, event.area.y, event.area.width, event.area.height)
    self.context.clip()
    #self.context.scale(event.area.width/300.0, event.area.height/300.0)
    #self.draw_point(10,10)
    #self.draw_points(110, 10)
    #self.draw_line(210, 10)
    self.draw(self.context)
    return False

  def draw(self, context):
    rect = self.drawing_area.get_allocation()
    x = rect.x + rect.width / 2
    y = rect.y + rect.height / 2

    radius = min(rect.width / 2, rect.height / 2) - 5

    # clock back
    context.arc(x, y, radius, 0, 2 * math.pi)
    context.set_source_rgb(1, 1, 1)
    context.fill_preserve()
    context.set_source_rgb(0, 0, 0)
    context.stroke()

    for i in xrange(12):
      inset = 0.1 * radius
      context.move_to(x + (radius - inset) * math.cos(i * math.pi / 6),
                      y + (radius - inset) * math.sin(i * math.pi / 6))
      context.line_to(x + radius * math.cos(i * math.pi / 6),
                      y + radius * math.sin(i * math.pi / 6))
      context.stroke()

    context.move_to(rect.x -5, rect.y -5)
    context.line_to(rect.x +100, rect.y -5)
    context.stroke()
    context.rectangle(rect.x, rect.y, rect.width, rect.height)
    context.stroke()

  def draw_line(self, x, y):
    self.context.move_to(x+10, y+10)
    self.context.line_to(x+20, y+30)
    self.context.stroke()
    self.context.move_to(x+5, y+50)
    self.context.show_text("Line")
    return

  def on_window1_destroy(self, object, data=None):
    gtk.main_quit()

if __name__ == "__main__":
  main = lathe()
  gtk.main()
